@@ -13,7 +13,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: xymonlaunch.c 6717 2011-08-01 21:15:13Z storner $";
+static char rcsid[] = "$Id: xymonlaunch.c 7085 2012-07-16 11:08:37Z storner $";
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -260,9 +260,10 @@ void load_config(char *conffn)
 		else if (curtask && (strncasecmp(p, "CRONDATE ", 9) == 0)) {
 			p+= 9;
 			xfreedup(curtask->cronstr,p);
-			if (curtask->crondate) { crondatefree(curtask->crondate);curtask->crondate=parse_cron_time(curtask->cronstr); }
+			if (curtask->crondate) crondatefree(curtask->crondate);
+			curtask->crondate = parse_cron_time(curtask->cronstr);
 			if (!curtask->crondate) {
-				errprintf("Can't parse cron date: %s->%s", curtask->key, curtask->cronstr);
+				errprintf("Can't parse cron date: %s->%s\n", curtask->key, curtask->cronstr);
 				curtask->disabled = 1;
 			}
 			curtask->interval = -1; /* disable interval */
@@ -291,7 +292,7 @@ void load_config(char *conffn)
 				curtask->depends = twalk;
 			}
 			else {
-				errprintf("Configuration error, unknown dependency %s->%s", curtask->key, p);
+				errprintf("Configuration error, unknown dependency %s->%s\n", curtask->key, p);
 			}
 		}
 		else if (curtask && (strncasecmp(p, "ENVFILE ", 8) == 0)) {
@@ -589,9 +590,9 @@ int main(int argc, char *argv[])
 	/* If using a logfile, switch stdout and stderr to go there */
 	if (logfn) {
 		/* Should we close stdin here ? No ... */
-		freopen("/dev/null", "r", stdin);
-		freopen(logfn, "a", stdout);
-		freopen(logfn, "a", stderr);
+		reopen_file("/dev/null", "r", stdin);
+		reopen_file(logfn, "a", stdout);
+		reopen_file(logfn, "a", stderr);
 	}
 
 	save_errbuf = 0;
@@ -612,8 +613,8 @@ int main(int argc, char *argv[])
 		}
 
 		if (logfn && dologswitch) {
-			freopen(logfn, "a", stdout);
-			freopen(logfn, "a", stderr);
+			reopen_file(logfn, "a", stdout);
+			reopen_file(logfn, "a", stderr);
 			dologswitch = 0;
 		}
 
@@ -720,8 +721,8 @@ int main(int argc, char *argv[])
 
 						dbgprintf("%s -> Assigning stdout/stderr to log '%s'\n", twalk->key, logfn);
 
-						freopen(logfn, "a", stdout);
-						freopen(logfn, "a", stderr);
+						reopen_file(logfn, "a", stdout);
+						reopen_file(logfn, "a", stderr);
 					}
 
 					/* Go! */
