@@ -11,7 +11,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: environ.c 6778 2011-11-28 12:34:12Z storner $";
+static char rcsid[] = "$Id: environ.c 7060 2012-07-14 16:32:11Z storner $";
 
 #include <ctype.h>
 #include <string.h>
@@ -215,7 +215,6 @@ void loadenv(char *envfile, char *area)
 	FILE *fd;
 	strbuffer_t *inbuf;
 	char *p, *oneenv;
-	int n;
 
 	MEMDEFINE(l);
 	inbuf = newstrbuffer(0);
@@ -277,7 +276,7 @@ void loadenv(char *envfile, char *area)
 					}
 				}
 
-				n = putenv(oneenv);
+				putenv(oneenv);
 			}
 		}
 		stackfclose(fd);
