@@ -13,7 +13,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: eventlog.c 6712 2011-07-31 21:01:52Z storner $";
+static char rcsid[] = "$Id: eventlog.c 7085 2012-07-16 11:08:37Z storner $";
 
 #include <limits.h>
 #include <stdio.h>
@@ -48,14 +48,6 @@ static int wanted_eventcolumn(char *service)
 	return result;
 }
 
-static char *string_time(time_t timestamp)
-{
-	static char result[20];
-
-	strftime(result, sizeof(result), "%Y/%m/%d@%H:%M:%S", localtime(&timestamp));
-	return result;
-}
-
 int record_compare(void **a, void **b)
 {
 	countlist_t **reca = (countlist_t **)a, **recb = (countlist_t **)b;
@@ -327,8 +319,6 @@ static void count_duration(time_t fromtime, time_t totime,
 			lastchange = ((color != -1) ? atol(strtok(NULL, "\n")) : totime+1);
 
 			if (hname && tname && (color != -1) && (strcmp(tname, icname) != 0) && (strcmp(tname, tcname) != 0)) {
-				int addrec = 1;
-
 				hrec = hostinfo(hname);
 				srec = getname(tname, 1);
 
@@ -349,8 +339,6 @@ static void count_duration(time_t fromtime, time_t totime,
 
 				/* See if we already have an event past the "totime" value */
 				if (lwalk->head) {
-					addrec = 0;
-
 					ed = lwalk->head;
 					while (ed && (ed->event->eventtime < totime)) ed = ed->next;
 
@@ -598,18 +586,21 @@ void do_eventlog(FILE *output, int maxcount, int maxminutes, char *fromtime, cha
 				if (ftello(eventlog) > maxcount*80) {
 					unsigned int uicurtime;
 					fseeko(eventlog, -maxcount*80, SEEK_CUR); 
-					fgets(l, sizeof(l), eventlog); /* Skip to start of line */
-					fgets(l, sizeof(l), eventlog);
-					sscanf(l, "%*s %*s %u %*u %*u %*s %*s %*d", &uicurtime);
-					curtime = uicurtime;
-					done = (curtime < firstevent);
-					if (unlimited && !done) maxcount += 1000;
+					if (fgets(l, sizeof(l), eventlog) &&  /* Skip to start of line */
+					    fgets(l, sizeof(l), eventlog)) {
+						sscanf(l, "%*s %*s %u %*u %*u %*s %*s %*d", &uicurtime);
+						curtime = uicurtime;
+						done = (curtime < firstevent);
+						if (unlimited && !done) maxcount += 1000;
+					}
+					else {
+						if (output) fprintf(output,"Error reading eventlog file %s: %s\n", eventlogfilename, strerror(errno));
+						return;
+					}
 				}
 				else {
-					off_t ofs;
 					rewind(eventlog);
 					curtime = 0;
-					ofs = ftello(eventlog);
 					done = 1;
 				}
 			} while (!done);
@@ -626,7 +617,7 @@ void do_eventlog(FILE *output, int maxcount, int maxminutes, char *fromtime, cha
 		unsigned int uievt, uicht, uidur;
 		char hostname[MAX_LINE_LEN], svcname[MAX_LINE_LEN], newcol[MAX_LINE_LEN], oldcol[MAX_LINE_LEN];
 		char *newcolname, *oldcolname;
-		int state, itemsfound, pagematch, hostmatch, testmatch, colrmatch;
+		int state, itemsfound, colrmatch;
 		event_t *newevent;
 		void *eventhost;
 		struct htnames_t *eventcolumn;
