@@ -12,7 +12,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: loadalerts.c 6795 2011-12-07 12:29:55Z storner $";
+static char rcsid[] = "$Id: loadalerts.c 7120 2012-07-24 16:24:39Z storner $";
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -481,8 +481,18 @@ int load_alertconfig(char *configfn, int defcolors, int defaultinterval)
 
 				if (firsttoken) { flush_rule(currule); currule = NULL; currcp = NULL; pstate = P_NONE; }
 				crit = setup_criteria(&currule, &currcp);
-				if (*(p+8) == '>') crit->minduration = 60*durationvalue(p+9);
-				else if (*(p+8) == '<') crit->maxduration = 60*durationvalue(p+9);
+				if (*(p+8) == '>') {
+					if (*(p+9) == '=')
+						crit->minduration = 60*durationvalue(p+10);
+					else
+						crit->minduration = 60*durationvalue(p+9) + 1;
+				}
+				else if (*(p+8) == '<') {
+					if (*(p+9) == '=')
+						crit->maxduration = 60*durationvalue(p+10);
+					else
+						crit->maxduration = 60*durationvalue(p+9) - 1;
+				}
 				else errprintf("Ignoring invalid DURATION at line %d: %s\n",cfid, p);
 				firsttoken = 0;
 			}
@@ -1042,7 +1052,10 @@ recip_t *next_recipient(activealerts_t *alert, int *first, int *anymatch, time_t
 			}
 		}
 		else {
-			if (recipwalk->next) {
+			if (!recipwalk) {
+				/* Should not happen! */
+			}
+			else if (recipwalk->next) {
 				/* Check the next recipient in the current rule */
 				recipwalk = recipwalk->next;
 			}
