@@ -13,7 +13,7 @@
 /*----------------------------------------------------------------------------*/
 
 
-static char rcsid[] = "$Id: loadhosts.c 6782 2011-11-30 11:53:42Z storner $";
+static char rcsid[] = "$Id: loadhosts.c 7085 2012-07-16 11:08:37Z storner $";
 
 #include <stdio.h>
 #include <string.h>
@@ -800,7 +800,7 @@ handlehost:
 
 		do {
 			*s = '\0';
-			printf("Pick item:"); fflush(stdout); fgets(s, sizeof(s), stdin);
+			printf("Pick item:"); fflush(stdout); if (!fgets(s, sizeof(s), stdin)) return 0;
 			p = strchr(s, '\n'); if (p) *p = '\0';
 			if (*s == '!') {
 				load_hostnames(argv[1], NULL, get_fqdn());
