@@ -11,7 +11,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: showgraph.c 6712 2011-07-31 21:01:52Z storner $";
+static char rcsid[] = "$Id: showgraph.c 7128 2012-07-28 06:29:24Z storner $";
 
 #include <limits.h>
 #include <stdio.h>
@@ -89,6 +89,7 @@ typedef struct gdef_t {
 	char *exfnpat;
 	char *title;
 	char *yaxis;
+	char *graphopts;
 	int  novzoom;
 	char **defs;
 	struct gdef_t *next;
@@ -127,9 +128,6 @@ void request_cacheflush(char *hostname)
 	struct dirent *d;
 	int ctlsocket = -1;
 
-	req = (char *)malloc(strlen(hostname)+3);
-	sprintf(req, "/%s/", hostname);
-
 	ctlsocket = socket(AF_UNIX, SOCK_DGRAM, 0);
 	if (ctlsocket == -1) {
 		errprintf("Cannot get socket: %s\n", strerror(errno));
@@ -138,6 +136,14 @@ void request_cacheflush(char *hostname)
 	fcntl(ctlsocket, F_SETFL, O_NONBLOCK);
 
 	dir = opendir(xgetenv("XYMONTMP"));
+	if (!dir) {
+		errprintf("Cannot acces $XYMONTMP directory: %s\n", strerror(errno));
+		return;
+	}
+
+	req = (char *)malloc(strlen(hostname)+3);
+	sprintf(req, "/%s/", hostname);
+
 	while ((d = readdir(dir)) != NULL) {
 		if (strncmp(d->d_name, "rrdctl.", 7) == 0) {
 			struct sockaddr_un myaddr;
@@ -180,7 +186,7 @@ void request_cacheflush(char *hostname)
 void parse_query(void)
 {
 	cgidata_t *cgidata = NULL, *cwalk;
-	char *stp;
+	char *stp = NULL;
 
 	cgidata = cgi_request();
 
@@ -364,6 +370,10 @@ void load_gdefs(char *fn)
 		else if (strncasecmp(p, "NOVZOOM", 7) == 0) {
 			newitem->novzoom = 1;
 		}
+		else if (strncasecmp(p, "GRAPHOPTIONS", 12) == 0) {
+			p += 12; p += strspn(p, " \t");
+			newitem->graphopts = strdup(p);
+		}
 		else if (haveupperlimit && (strncmp(p, "-u ", 3) == 0)) {
 			continue;
 		}
@@ -679,7 +689,6 @@ void graph_link(FILE *output, char *uri, char *grtype, time_t seconds)
 char *build_selfURI(void)
 {
 	strbuffer_t *result = newstrbuffer(2048);
-	char *p;
 	char numbuf[40];
 
 	addtobuffer(result, xgetenv("SCRIPT_NAME"));
@@ -782,6 +791,10 @@ void generate_graph(char *gdeffn, char *rrddir, char *graphfn)
 	int xsize, ysize;
 	double ymin, ymax;
 
+	char *useroptval = NULL;
+	char **useropts = NULL;
+	int useroptcount = 0, useroptidx;
+
 	/* Find the graphs.cfg file and load it */
 	if (gdeffn == NULL) {
 		char fnam[PATH_MAX];
@@ -1040,7 +1053,7 @@ void generate_graph(char *gdeffn, char *rrddir, char *graphfn)
 		}
 		pfd = popen(pcmd, "r");
 		if (pfd) {
-			fgets(graphtitle, sizeof(graphtitle), pfd);
+			if (fgets(graphtitle, sizeof(graphtitle), pfd) == NULL) *graphtitle = '\0';
 			pclose(pfd);
 		}
 
@@ -1054,6 +1067,27 @@ void generate_graph(char *gdeffn, char *rrddir, char *graphfn)
 	sprintf(heightopt, "-h%d", graphheight);
 	sprintf(widthopt, "-w%d", graphwidth);
 
+	/*
+	 * Grab user-provided additional rrd_graph options from RRDGRAPHOPTS
+	 */
+	useroptcount = 0;
+	useroptval = gdef->graphopts;
+	if (!useroptval) useroptval = getenv("RRDGRAPHOPTS");
+	if (useroptval) {
+		char *tok;
+
+		useropts = (char **)calloc(1, sizeof(char *));
+		useroptval = strdup(useroptval);
+		tok = strtok(useroptval, " ");
+		while (tok) {
+			useroptcount++;
+			useropts = (char **)realloc(useropts, (useroptcount+1)*sizeof(char *));
+			useropts[useroptcount-1] = tok;
+			useropts[useroptcount] = NULL;
+			tok = strtok(NULL, " ");
+		}
+	}
+
 	/*
 	 * Setup the arguments for calling rrd_graph. 
 	 * There's up to 16 standard arguments, plus the 
@@ -1061,7 +1095,7 @@ void generate_graph(char *gdeffn, char *rrddir, char *graphfn)
 	 * there are multiple RRD-files to handle).
 	 */
 	for (pcount = 0; (gdef->defs[pcount]); pcount++) ;
-	rrdargs = (char **) calloc(16 + pcount*rrddbcount + 1, sizeof(char *));
+	rrdargs = (char **) calloc(16 + pcount*rrddbcount + useroptcount + 1, sizeof(char *));
 
 
 	argi = 0;
@@ -1095,6 +1129,10 @@ void generate_graph(char *gdeffn, char *rrddir, char *graphfn)
 		rrdargs[argi++] = endopt;
 	}
 
+	for (useroptidx=0; (useroptidx < useroptcount); useroptidx++) {
+		rrdargs[argi++] = useropts[useroptidx];
+	}
+
 	for (rrdidx=0; (rrdidx < rrddbcount); rrdidx++) {
 		if ((firstidx == -1) || ((rrdidx >= firstidx) && (rrdidx <= lastidx))) {
 			int i;
@@ -1166,6 +1204,9 @@ void generate_graph(char *gdeffn, char *rrddir, char *graphfn)
 
 		errormsg(rrd_get_error());
 	}
+
+	if (useroptval) xfree(useroptval);
+	if (useropts) xfree(useropts);
 }
 
 void generate_zoompage(char *selfURI)
