@@ -11,7 +11,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: xymond_client.c 6792 2011-12-06 15:25:18Z storner $";
+static char rcsid[] = "$Id: xymond_client.c 7149 2012-08-01 16:16:57Z storner $";
 
 #include <stdio.h>
 #include <string.h>
@@ -509,7 +509,6 @@ void unix_disk_report(char *hostname, char *clientclass, enum ostype_t os,
 {
 	int diskcolor = COL_GREEN;
 
-	int dchecks = 0;
 	int freecol = -1;
 	int capacol = -1;
 	int mntcol  = -1;
@@ -527,7 +526,7 @@ void unix_disk_report(char *hostname, char *clientclass, enum ostype_t os,
 
 	monmsg = newstrbuffer(0);
 	dfstr_filtered = newstrbuffer(0);
-	dchecks = clear_disk_counts(hinfo, clientclass);
+	clear_disk_counts(hinfo, clientclass);
 	clearalertgroups();
 
 	bol = dfstr; /* Must do this always, to at least grab the column-numbers we need */
@@ -665,7 +664,7 @@ void unix_disk_report(char *hostname, char *clientclass, enum ostype_t os,
 	sprintf(msgline, "%s.disk %s %s - Filesystems %s\n",
 		commafy(hostname), colorname(diskcolor), 
 		(timestr ? timestr : "<No timestamp data>"), 
-		((diskcolor == COL_GREEN) ? "OK" : "NOT ok"));
+		(((diskcolor == COL_RED) || (diskcolor == COL_YELLOW)) ? "NOT ok" : "ok"));
 	addtostatus(msgline);
 
 	/* And add the info about what's wrong */
@@ -690,7 +689,6 @@ void unix_inode_report(char *hostname, char *clientclass, enum ostype_t os,
 {
 	int inodecolor = COL_GREEN;
 
-	int ichecks = 0;
 	int freecol = -1;
 	int capacol = -1;
 	int mntcol  = -1;
@@ -708,7 +706,7 @@ void unix_inode_report(char *hostname, char *clientclass, enum ostype_t os,
 
 	monmsg = newstrbuffer(0);
 	dfstr_filtered = newstrbuffer(0);
-	ichecks = clear_inode_counts(hinfo, clientclass);
+	clear_inode_counts(hinfo, clientclass);
 	clearalertgroups();
 
 	bol = dfstr; /* Must do this always, to at least grab the column-numbers we need */
@@ -789,9 +787,6 @@ void unix_inode_report(char *hostname, char *clientclass, enum ostype_t os,
 
 					addtobuffer(monmsg, msgline);
 					addalertgroup(group);
-				} else {
-					msgp += sprintf(msgp, "&green <!-- ID=%s --> %s OK\n", fsname, fsname);
-					addtobuffer(monmsg, msgline);
 				}
 			}
 
@@ -806,14 +801,22 @@ void unix_inode_report(char *hostname, char *clientclass, enum ostype_t os,
 	}
 
 	if ((capacol == -1) && (mntcol == -1)) {
-		/* If this happens, we havent found our headers so no filesystems have been processed */
-		inodecolor = COL_YELLOW;
-		sprintf(msgline, "&red Expected strings (%s and %s) not found in df output\n", 
-			capahdr, mnthdr);
-		addtobuffer(monmsg, msgline);
-
-		errprintf("Host %s (%s) sent incomprehensible inode report - missing columnheaders '%s' and '%s'\n%s\n",
-			  hostname, osname(os), capahdr, mnthdr, dfstr);
+		if (strlen(dfstr) == 0) {
+			/* Empty inode report, happens on Solaris when all filesystems are ZFS */
+			inodecolor = COL_GREEN;
+			sprintf(msgline, "&green No filesystems reporting inode data\n");
+			addtobuffer(monmsg, msgline);
+		}
+		else {
+			/* If this happens, we havent found our headers so no filesystems have been processed */
+			inodecolor = COL_YELLOW;
+			sprintf(msgline, "&red Expected strings (%s and %s) not found in df output\n", 
+				capahdr, mnthdr);
+			addtobuffer(monmsg, msgline);
+	
+			errprintf("Host %s (%s) sent incomprehensible inode report - missing columnheaders '%s' and '%s'\n%s\n",
+				  hostname, osname(os), capahdr, mnthdr, dfstr);
+		}
 	}
 
 	/* Check for filesystems that must (not) exist */
@@ -849,7 +852,7 @@ void unix_inode_report(char *hostname, char *clientclass, enum ostype_t os,
 	sprintf(msgline, "%s.inode %s %s - Filesystems %s\n",
 		commafy(hostname), colorname(inodecolor), 
 		(timestr ? timestr : "<No timestamp data>"), 
-		((inodecolor == COL_GREEN) ? "OK" : "NOT ok"));
+		(((inodecolor == COL_RED) || (inodecolor == COL_YELLOW)) ? "NOT ok" : "ok"));
 	addtostatus(msgline);
 
 	/* And add the info about what's wrong */
@@ -1103,7 +1106,7 @@ void unix_procs_report(char *hostname, char *clientclass, enum ostype_t os,
 	sprintf(msgline, "%s.procs %s %s - Processes %s\n",
 		commafy(hostname), colorname(pscolor), 
 		(timestr ? timestr : "<No timestamp data>"), 
-		((pscolor == COL_GREEN) ? "OK" : "NOT ok"));
+		(((pscolor == COL_RED) || (pscolor == COL_YELLOW)) ? "NOT ok" : "ok"));
 	addtostatus(msgline);
 
 	/* And add the info about what's wrong */
@@ -1282,9 +1285,10 @@ void msgs_report(char *hostname, char *clientclass, enum ostype_t os,
 	if (group) sprintf(msgline, "status/group:%s ", group); else strcpy(msgline, "status ");
 	addtostatus(msgline);
 
-	sprintf(msgline, "%s.msgs %s System logs at %s\n",
+	sprintf(msgline, "%s.msgs %s %s - System logs %s\n",
 		commafy(hostname), colorname(msgscolor), 
-		(timestr ? timestr : "<No timestamp data>"));
+		(timestr ? timestr : "<No timestamp data>"),
+		(((msgscolor == COL_RED) || (msgscolor == COL_YELLOW)) ? "NOT ok" : "ok"));
 	addtostatus(msgline);
 
 	if (STRBUFLEN(reddata)) {
@@ -1476,9 +1480,10 @@ void file_report(char *hostname, char *clientclass, enum ostype_t os,
 		if (group) sprintf(msgline, "status/group:%s ", group); else strcpy(msgline, "status ");
 		addtostatus(msgline);
 
-		sprintf(msgline, "%s.files %s Files status at %s\n",
+		sprintf(msgline, "%s.files %s %s - Files %s\n",
 			commafy(hostname), colorname(filecolor), 
-			(timestr ? timestr : "<No timestamp data>"));
+			(timestr ? timestr : "<No timestamp data>"),
+			(((filecolor == COL_RED) || (filecolor == COL_YELLOW)) ? "NOT ok" : "ok"));
 		addtostatus(msgline);
 
 		if (STRBUFLEN(reddata)) {
@@ -1723,7 +1728,7 @@ void unix_ports_report(char *hostname, char *clientclass, enum ostype_t os,
 		sprintf(msgline, "%s.ports %s %s - Ports %s\n",
 			commafy(hostname), colorname(portcolor), 
 			(timestr ? timestr : "<No timestamp data>"), 
-			((portcolor == COL_GREEN) ? "OK" : "NOT ok"));
+			(((portcolor == COL_RED) || (portcolor == COL_YELLOW)) ? "NOT ok" : "ok"));
 		addtostatus(msgline);
 
 		/* And add the info about what's wrong */
@@ -1791,7 +1796,6 @@ void testmode(char *configfn)
 	void *hinfo, *oldhinfo = NULL;
 	char hostname[1024], clientclass[1024];
 	char s[4096];
-	int cfid;
 
 	load_hostnames(xgetenv("HOSTSCFG"), NULL, get_fqdn());
 	load_client_config(configfn);
@@ -1802,7 +1806,7 @@ void testmode(char *configfn)
 		hinfo = NULL;
 		while (!hinfo) {
 			printf("Hostname (.=end, ?=dump, !=reload) [%s]: ", hostname); 
-			fflush(stdout); fgets(hostname, sizeof(hostname), stdin);
+			fflush(stdout); if (!fgets(hostname, sizeof(hostname), stdin)) return;
 			clean_instr(hostname);
 
 			if (strlen(hostname) == 0) {
@@ -1826,20 +1830,20 @@ void testmode(char *configfn)
 				if (!hinfo) printf("Unknown host\n");
 
 				printf("Hosttype [%s]: ", clientclass); 
-				fflush(stdout); fgets(clientclass, sizeof(clientclass), stdin);
+				fflush(stdout); if (!fgets(clientclass, sizeof(clientclass), stdin)) return;
 				clean_instr(clientclass);
 			}
 		}
 		oldhinfo = hinfo;
 
 		printf("Test (cpu, mem, disk, proc, log, port): "); fflush(stdout); 
-		fgets(s, sizeof(s), stdin); clean_instr(s);
+		if (!fgets(s, sizeof(s), stdin)) return; clean_instr(s);
 		if (strcmp(s, "cpu") == 0) {
 			float loadyellow, loadred;
 			int recentlimit, ancientlimit, uptimecolor;
 			int maxclockdiff, clockdiffcolor;
 
-			cfid = get_cpu_thresholds(hinfo, clientclass, &loadyellow, &loadred, &recentlimit, &ancientlimit, &uptimecolor, &maxclockdiff, &clockdiffcolor);
+			get_cpu_thresholds(hinfo, clientclass, &loadyellow, &loadred, &recentlimit, &ancientlimit, &uptimecolor, &maxclockdiff, &clockdiffcolor);
 
 			printf("Load: Yellow at %.2f, red at %.2f\n", loadyellow, loadred);
 			printf("Uptime: %s from boot until %s,", colorname(uptimecolor), durationstring(recentlimit));
@@ -1861,8 +1865,8 @@ void testmode(char *configfn)
 			char *groups;
 
 			printf("Filesystem: "); fflush(stdout);
-			fgets(s, sizeof(s), stdin); clean_instr(s);
-			cfid = get_disk_thresholds(hinfo, clientclass, s, &warnlevel, &paniclevel, 
+			if (!fgets(s, sizeof(s), stdin)) return; clean_instr(s);
+			get_disk_thresholds(hinfo, clientclass, s, &warnlevel, &paniclevel, 
 						   &abswarn, &abspanic, &ignored, &groups);
 			if (ignored) 
 				printf("Ignored\n");
@@ -1886,7 +1890,7 @@ void testmode(char *configfn)
 			printf("To read 'ps' data from a file, enter '@FILENAME' at the prompt\n");
 			do {
 				printf("ps command string: "); fflush(stdout);
-				fgets(s, sizeof(s), stdin); clean_instr(s);
+				if (!fgets(s, sizeof(s), stdin)) return; clean_instr(s);
 				if (*s == '@') {
 					fd = fopen(s+1, "r");
 					while (fd && fgets(s, sizeof(s), fd)) {
@@ -1912,7 +1916,7 @@ void testmode(char *configfn)
 			int logcolor;
 
 			printf("log filename: "); fflush(stdout);
-			fgets(s, sizeof(s), stdin); clean_instr(s);
+			if (!fgets(s, sizeof(s), stdin)) return; clean_instr(s);
 			sectname = (char *)malloc(strlen(s) + 20);
 			sprintf(sectname, "msgs:%s", s);
 
@@ -1922,7 +1926,7 @@ void testmode(char *configfn)
 			printf("To read log data from a file, enter '@FILENAME' at the prompt\n");
 			do {
 				printf("log line: "); fflush(stdout);
-				fgets(s, sizeof(s), stdin); clean_instr(s);
+				if (!fgets(s, sizeof(s), stdin)) return; clean_instr(s);
 				if (*s == '@') {
 					fd = fopen(s+1, "r");
 					while (fd && fgets(s, sizeof(s), fd)) {
@@ -1956,13 +1960,13 @@ void testmode(char *configfn)
 
 			printf("Need to know netstat columns for 'Local address', 'Remote address' and 'State'\n");
 			printf("Enter columns [%d %d %d]: ", localcol, remotecol, statecol); fflush(stdout);
-			fgets(s, sizeof(s), stdin); clean_instr(s);
+			if (!fgets(s, sizeof(s), stdin)) return; clean_instr(s);
 			if (*s) sscanf(s, "%d %d %d", &localcol, &remotecol, &statecol);
 
 			printf("To read 'netstat' data from a file, enter '@FILENAME' at the prompt\n");
 			do {
 				printf("netstat line: "); fflush(stdout);
-				fgets(s, sizeof(s), stdin); clean_instr(s);
+				if (!fgets(s, sizeof(s), stdin)) return; clean_instr(s);
 				if (*s == '@') {
 					FILE *fd;
 
@@ -2266,8 +2270,8 @@ int main(int argc, char *argv[])
 		else if (strncmp(metadata[0], "@@logrotate", 11) == 0) {
 			char *fn = xgetenv("XYMONCHANNEL_LOGFILENAME");
 			if (fn && strlen(fn)) {
-				freopen(fn, "a", stdout);
-				freopen(fn, "a", stderr);
+				reopen_file(fn, "a", stdout);
+				reopen_file(fn, "a", stderr);
 			}
 			continue;
 		}
