@@ -13,7 +13,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: xymond_history.c 6748 2011-09-04 17:24:36Z storner $";
+static char rcsid[] = "$Id: xymond_history.c 7136 2012-08-01 08:51:24Z storner $";
 
 #include <sys/types.h>
 #include <stdio.h>
@@ -160,7 +160,7 @@ int main(int argc, char *argv[])
 	{
 		FILE *pidfd = fopen(pidfn, "w");
 		if (pidfd) {
-			fprintf(pidfd, "%d\n", getpid());
+			fprintf(pidfd, "%lu\n", (unsigned long)getpid());
 			fclose(pidfd);
 		}
 	}
@@ -318,7 +318,6 @@ int main(int argc, char *argv[])
 
 					while (!gotit) {
 						off_t tmppos = ftello(statuslogfd);
-						time_t dur;
 						int dur_i;
 
 						if (fgets(l, sizeof(l)-1, statuslogfd)) {
@@ -332,7 +331,6 @@ int main(int argc, char *argv[])
 								 */
 								pos = tmppos;
 								lastchg = lastchg_i;
-								dur = dur_i;
 							}
 						}
 						else {
@@ -771,8 +769,8 @@ int main(int argc, char *argv[])
 		else if (strncmp(metadata[0], "@@logrotate", 11) == 0) {
 			char *fn = xgetenv("XYMONCHANNEL_LOGFILENAME");
 			if (fn && strlen(fn)) {
-				freopen(fn, "a", stdout);
-				freopen(fn, "a", stderr);
+				reopen_file(fn, "a", stdout);
+				reopen_file(fn, "a", stderr);
 			}
 			continue;
 		}
