@@ -18,7 +18,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: xymond_locator.c 6745 2011-09-04 06:01:06Z storner $";
+static char rcsid[] = "$Id: xymond_locator.c 7085 2012-07-16 11:08:37Z storner $";
 
 #include "config.h"
 
@@ -465,8 +465,8 @@ void sigmisc_handler(int signum)
 
 	  case SIGHUP:
 		if (logfile) {
-			freopen(logfile, "a", stdout);
-			freopen(logfile, "a", stderr);
+			reopen_file(logfile, "a", stdout);
+			reopen_file(logfile, "a", stderr);
 			errprintf("Caught SIGHUP, reopening logfile\n");
 		}
 		break;
@@ -709,8 +709,8 @@ int main(int argc, char *argv[])
 
 	/* Redirect logging to the logfile, if requested */
 	if (logfile) {
-		freopen(logfile, "a", stdout);
-		freopen(logfile, "a", stderr);
+		reopen_file(logfile, "a", stdout);
+		reopen_file(logfile, "a", stderr);
 	}
 
 	errprintf("Xymon locator version %s starting\n", VERSION);
@@ -719,7 +719,7 @@ int main(int argc, char *argv[])
 	if (daemonize) {
 		pid_t childpid;
 
-		freopen("/dev/null", "a", stdin);
+		reopen_file("/dev/null", "r", stdin);
 
 		/* Become a daemon */
 		childpid = fork();
