@@ -10,7 +10,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: xymonfetch.c 6745 2011-09-04 06:01:06Z storner $";
+static char rcsid[] = "$Id: xymonfetch.c 7058 2012-07-14 15:01:11Z storner $";
 
 #include "config.h"
 
@@ -574,7 +574,7 @@ int main(int argc, char *argv[])
 			/* Set by SIGUSR1 - dump the list of active requests */
 			dumpsessions = 0;
 			for (connwalk = chead; (connwalk); connwalk = connwalk->next) {
-				char *ctypestr, *actionstr;
+				char *ctypestr = "?", *actionstr = "?";
 				char timestr[30];
 
 				switch (connwalk->ctype) {
