@@ -10,7 +10,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: loaddata.c 6712 2011-07-31 21:01:52Z storner $";
+static char rcsid[] = "$Id: loaddata.c 7117 2012-07-24 15:48:41Z storner $";
 
 #include <limits.h>
 #include <stdio.h>
@@ -136,7 +136,6 @@ state_t *init_state(char *filename, logdata_t *log)
 	struct stat 	log_st;
 	time_t		now = getcurrenttime(NULL);
 	time_t		histentry_start;
-	int		logexpired = 0;
 	int		propagating, isacked;
 
 	dbgprintf("init_state(%s, %d, ...)\n", textornull(filename));
@@ -166,7 +165,6 @@ state_t *init_state(char *filename, logdata_t *log)
 	if (!reportstart && !snapshot) {
 		hostname = strdup(log->hostname);
 		testname = strdup(log->testname);
-		logexpired = (log->validtime < now);
 	}
 	else {
 		sprintf(fullfn, "%s/%s", xgetenv("XYMONHISTDIR"), filename);
@@ -180,7 +178,6 @@ state_t *init_state(char *filename, logdata_t *log)
 		}
 
 		/* Pick out host- and test-name */
-		logexpired = (log_st.st_mtime < now);
 		hostname = strdup(filename);
 		p = strrchr(hostname, '.');
 
@@ -276,9 +273,10 @@ state_t *init_state(char *filename, logdata_t *log)
 		newstate->entry->causes = (dynamicreport ? NULL : save_replogs());
 	}
 	else if (snapshot) {
-		time_t fileage = snapshot - histentry_start;
+		time_t fileage;
 
 		newstate->entry->color = history_color(fd, snapshot, &histentry_start, &newstate->entry->histlogname);
+		fileage = snapshot - histentry_start;
 
 		newstate->entry->oldage = (fileage >= recentgif_limit);
 		newstate->entry->fileage = fileage;
@@ -401,7 +399,7 @@ void generate_compactitems(state_t **topstate)
 	hostlist_t 	*h;
 	entry_t		*e;
 	char *compacted;
-	char *tok1, *tok2, *savep1, *savep2;
+	char *tok1, *savep1, *savep2;
 	compact_t *itm;
 	int i;
 	state_t *newstate;
@@ -498,10 +496,11 @@ state_t *load_state(dispsummary_t **sumhead)
 			if (stat(dumpfn, &st) == 0) {
 				fd = fopen(dumpfn, "r");
 				if (fd) {
-					board = (char *)malloc(st.st_size + 1);
-					fread(board, 1, st.st_size, fd);
-					fclose(fd);
-					xymondresult = XYMONSEND_OK;
+					board = (char *)malloc(st.st_size + 1); *board = '\0';
+					if (fread(board, 1, st.st_size, fd)) {
+						fclose(fd);
+						xymondresult = XYMONSEND_OK;
+					}
 				}
 			}
 		}
