@@ -11,7 +11,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: pagegen.c 6775 2011-11-27 21:28:18Z storner $";
+static char rcsid[] = "$Id: pagegen.c 7085 2012-07-16 11:08:37Z storner $";
 
 #include <limits.h>
 #include <stdio.h>
@@ -332,8 +332,7 @@ void do_vertical(host_t *head, FILE *output, char *pagepath)
 	host_t	*h;
 	entry_t	*e;
 	char	*xymonskin;
-	int	rowcount = 0, hostcount = 0;
-	int     usetooltip = 0;
+	int	hostcount = 0;
 	int	width;
 	int	hidx;
 	void	*vptree;
@@ -346,11 +345,6 @@ void do_vertical(host_t *head, FILE *output, char *pagepath)
 
 	xymonskin = strdup(xgetenv("XYMONSKIN"));
 
-	switch (tooltipuse) {
-	  case TT_STDONLY: case TT_ALWAYS: usetooltip = 1; break;
-	  case TT_NEVER:  usetooltip = 0; break;
-	}
-
 	width = atoi(xgetenv("DOTWIDTH"));
 	if ((width < 0) || (width > 50)) width = 16;
 	width += 4;
@@ -373,7 +367,6 @@ void do_vertical(host_t *head, FILE *output, char *pagepath)
 	for (h = head, hidx = 0; (h); h = h->next, hidx++) {
 		for (e = h->entries; (e); e = e->next) {
 			vprec_t *itm;
-			char *hptr;
 
 			handle = xtreeFind(vptree, e->column->name);
 			if (handle == xtreeEnd(vptree)) {
@@ -891,7 +884,10 @@ void do_one_page(xymongen_page_t *page, dispsummary_t *sums, int embedded)
 	char	*dirdelim;
 	char	*localtext;
 
-	getcwd(curdir, sizeof(curdir));
+	if (!getcwd(curdir, sizeof(curdir))) {
+		errprintf("Cannot get current directory: %s\n", strerror(errno));
+		return;
+	}
 	localtext = strdup(xgetenv((page->parent ? "XYMONPAGESUBLOCAL" : "XYMONPAGELOCAL")));
 
 	pagepath[0] = '\0';
@@ -906,8 +902,10 @@ void do_one_page(xymongen_page_t *page, dispsummary_t *sums, int embedded)
 			sprintf(filename, "xymon%s", htmlextension);
 			sprintf(rssfilename, "xymon%s", rssextension);
 			sprintf(indexfilename, "index%s", htmlextension);
-			unlink(indexfilename); symlink(filename, indexfilename);
-			dbgprintf("Symlinking %s -> %s\n", filename, indexfilename);
+			unlink(indexfilename); 
+			if (symlink(filename, indexfilename)) {
+				dbgprintf("Symlinking %s -> %s\n", filename, indexfilename);
+			}
 		}
 		else {
 			char tmppath[PATH_MAX];
