@@ -10,7 +10,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: httptest.c 6712 2011-07-31 21:01:52Z storner $";
+static char rcsid[] = "$Id: httptest.c 7123 2012-07-26 07:17:02Z storner $";
 
 #include <sys/types.h>
 #include <limits.h>
@@ -20,6 +20,7 @@ static char rcsid[] = "$Id: httptest.c 6712 2011-07-31 21:01:52Z storner $";
 #include <regex.h>
 #include <ctype.h>
 #include <sys/stat.h>
+#include <errno.h>
 
 #include "version.h"
 #include "libxymon.h"
@@ -539,11 +540,19 @@ void add_http_test(testitem_t *t)
 				struct stat st;
 
 				if (fstat(fileno(pf), &st) == 0) {
+					int n;
+
 					xfree(httptest->weburl.postdata);
-					httptest->weburl.postdata = (char *)malloc(st.st_size + 1);
-					fread(httptest->weburl.postdata, 1, st.st_size, pf);
-					*(httptest->weburl.postdata+st.st_size) = '\0';
-					contlen = st.st_size;
+					httptest->weburl.postdata = (char *)malloc(st.st_size + 1); *(httptest->weburl.postdata) = '\0';
+					n = fread(httptest->weburl.postdata, 1, st.st_size, pf);
+					if (n == st.st_size) {
+						*(httptest->weburl.postdata+n) = '\0';
+						contlen = n;
+					}
+					else {
+						errprintf("Cannot read file %s: %s\n", httptest->weburl.postdata+5, strerror(errno));
+						contlen = 0;
+					}
 				}
 				else {
 					errprintf("Cannot stat file %s\n", httptest->weburl.postdata+5);
